import{_ as d,u as c,w as _,a as m,S as f}from"./StreamlitVue.n2C9d_MV.js";/* empty css                               */import{d as l,r as S,o as u,c as g,a as b,j as v,k as B,m as V,l as x,t as C,b as D}from"./runtime-dom.esm-bundler.gORlFm-p.js";/* empty css                               */const k=l({__name:"DsfrRadioButtonSet",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(o,{expose:r}){r(),c();const t=o,e=S(t.args.modelValue||"");function n(i){return i?!t.disabled&&!t.args.disabled?i:i.map(p=>(p.disabled=!0,p)):[]}function s(){m.setComponentValue(e.value)}const a={props:t,value:e,parseOptions:n,onUpdateModelValue:s,get DsfrRadioButtonSet(){return _}};return Object.defineProperty(a,"__isScriptSetup",{enumerable:!1,value:!0}),a}}),y={class:"component"};function R(o,r,t,e,n,s){return u(),g("div",y,[b(e.DsfrRadioButtonSet,V(e.props.args,{options:e.parseOptions(e.props.args.options),modelValue:e.value,"onUpdate:modelValue":[r[0]||(r[0]=a=>e.value=a),e.onUpdateModelValue]}),v({_:2},[e.props.args.requiredTip?{name:"required-tip",fn:B(()=>[x(C(e.props.args.requiredTip),1)]),key:"0"}:void 0]),1040,["options","modelValue"])])}const h=d(k,[["render",R],["__scopeId","data-v-2d83e30f"]]),w=l({__name:"DsfrRadioButtonSet",setup(o,{expose:r}){r();const t={StreamlitComponent:f,Component:h};return Object.defineProperty(t,"__isScriptSetup",{enumerable:!1,value:!0}),t}});function O(o,r,t,e,n,s){return u(),D(e.StreamlitComponent,{component:e.Component,"client:load":""})}const U=d(w,[["render",O]]);export{U as default};
