.component[data-v-940a2f31] .fr-range[data-fr-js-range]:after{clip-path:polygon(var(--progress-left) 0,calc(var(--progress-right) - 24px) 0,calc(var(--progress-right) - 24px) 100%,var(--progress-left) 100%)}
