import{_ as m,u as g,G as y,a as u,S}from"./StreamlitVue.n2C9d_MV.js";/* empty css                               */import{d as f,r as d,o as v,c as I,a as V,j as x,k as c,m as B,l as i,t as _,b as C}from"./runtime-dom.esm-bundler.gORlFm-p.js";/* empty css                               */const k=f({__name:"DsfrInput",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(r,{expose:o}){o(),g();const a=r,e=d(a.args.modelValue||""),n=d(e.value),p={props:a,value:e,lastValue:n,onInput:t=>{const b=t.target;e.value=b.value},onBlur:()=>{e.value!==n.value&&(n.value=e.value,u.setComponentValue(e.value))},onKeydown:t=>{t.key==="Enter"&&e.value!==n.value&&(n.value=e.value,u.setComponentValue(e.value))},get DsfrInput(){return y}};return Object.defineProperty(p,"__isScriptSetup",{enumerable:!1,value:!0}),p}}),w={class:"component"};function D(r,o,a,e,n,s){return v(),I("div",w,[V(e.DsfrInput,B(e.props.args,{disabled:e.props.disabled||e.props.args.disabled,modelValue:e.value,"onUpdate:modelValue":o[0]||(o[0]=l=>e.value=l),onInput:e.onInput,onBlur:e.onBlur,onKeydown:e.onKeydown}),x({_:2},[e.props.args.label?{name:"label",fn:c(()=>[i(_(e.props.args.label),1)]),key:"0"}:void 0,e.props.args.requiredTip?{name:"required-tip",fn:c(()=>[i(_(e.props.args.requiredTip),1)]),key:"1"}:void 0]),1040,["disabled","modelValue"])])}const h=m(k,[["render",D],["__scopeId","data-v-c6b7fac2"]]),K=f({__name:"DsfrInput",setup(r,{expose:o}){o();const a={StreamlitComponent:S,Component:h};return Object.defineProperty(a,"__isScriptSetup",{enumerable:!1,value:!0}),a}});function j(r,o,a,e,n,s){return v(),C(e.StreamlitComponent,{component:e.Component,"client:load":""})}const N=m(K,[["render",j]]);export{N as default};
