import{_ as c,u as v,E as b,a as S,S as V}from"./StreamlitVue.n2C9d_MV.js";/* empty css                               */import{d as u,r as m,o as _,c as x,a as C,j as h,k as l,m as k,l as p,t as i,b as y}from"./runtime-dom.esm-bundler.gORlFm-p.js";/* empty css                               */const D=u({__name:"DsfrRange",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(s,{expose:t}){t(),v();const o=s,e=m(o.args.modelValue||""),r=m(e.value);let a=null;function n(){e.value!==r.value&&(r.value=e.value,S.setComponentValue(e.value))}function f(){a&&(clearTimeout(a),a=null),a=setTimeout(n,200)}const d={props:o,value:e,lastValue:r,get timeoutUpdate(){return a},set timeoutUpdate(g){a=g},setComponentValue:n,onUpdateModelValue:f,get DsfrRange(){return b}};return Object.defineProperty(d,"__isScriptSetup",{enumerable:!1,value:!0}),d}}),U={class:"component"};function R(s,t,o,e,r,a){return _(),x("div",U,[C(e.DsfrRange,k(e.props.args,{disabled:e.props.disabled||e.props.args.disabled,modelValue:e.value,"onUpdate:modelValue":[t[0]||(t[0]=n=>e.value=n),e.onUpdateModelValue]}),h({_:2},[e.props.args.label?{name:"label",fn:l(()=>[p(i(e.props.args.label),1)]),key:"0"}:void 0,e.props.args.hint?{name:"hint",fn:l(()=>[p(i(e.props.args.hint),1)]),key:"1"}:void 0,e.props.args.messages?{name:"messages",fn:l(()=>[p(i(e.props.args.messages),1)]),key:"2"}:void 0]),1040,["disabled","modelValue"])])}const B=c(D,[["render",R],["__scopeId","data-v-940a2f31"]]),j=u({__name:"DsfrRange",setup(s,{expose:t}){t();const o={StreamlitComponent:V,Component:B};return Object.defineProperty(o,"__isScriptSetup",{enumerable:!1,value:!0}),o}});function E(s,t,o,e,r,a){return _(),y(e.StreamlitComponent,{component:e.Component,"client:load":""})}const N=c(j,[["render",E]]);export{N as default};
