import{_ as n,u as i,c as l,S as m}from"./StreamlitVue.n2C9d_MV.js";import{d as s,o as t,c as g,a as k,b as _}from"./runtime-dom.esm-bundler.gORlFm-p.js";/* empty css                               */const L=s({__name:"DsfrFooter",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(a,{expose:o}){o(),i();const r={props:a,get DsfrFooter(){return l}};return Object.defineProperty(r,"__isScriptSetup",{enumerable:!1,value:!0}),r}}),d={class:"component"};function f(a,o,e,r,p,c){return t(),g("div",d,[k(r.DsfrFooter,{beforeMandatoryLinks:r.props.args.beforeMandatoryLinks,afterMandatoryLinks:r.props.args.afterMandatoryLinks,a11yCompliance:r.props.args.a11yCompliance,logoText:r.props.args.logoText,legalLink:r.props.args.legalLink,personalDataLink:r.props.args.personalDataLink,cookiesLink:r.props.args.cookiesLink,a11yComplianceLink:r.props.args.a11yComplianceLink,descText:r.props.args.descText,homeLink:r.props.args.homeLink,licenceText:r.props.args.licenceText,licenceTo:r.props.args.licenceTo,licenceName:r.props.args.licenceName,licenceLinkProps:r.props.args.licenceLinkProps,ecosystemLinks:r.props.args.ecosystemLinks,partners:r.props.args.partners,mandatoryLinks:r.props.args.mandatoryLinks,operatorLinkText:r.props.args.operatorLinkText,operatorTo:r.props.args.operatorTo,operatorImgStyle:r.props.args.operatorImgStyle,operatorImgSrc:r.props.args.operatorImgSrc,operatorImgAlt:r.props.args.operatorImgAlt},null,8,["beforeMandatoryLinks","afterMandatoryLinks","a11yCompliance","logoText","legalLink","personalDataLink","cookiesLink","a11yComplianceLink","descText","homeLink","licenceText","licenceTo","licenceName","licenceLinkProps","ecosystemLinks","partners","mandatoryLinks","operatorLinkText","operatorTo","operatorImgStyle","operatorImgSrc","operatorImgAlt"])])}const y=n(L,[["render",f]]),x=s({__name:"DsfrFooter",setup(a,{expose:o}){o();const e={StreamlitComponent:m,Component:y};return Object.defineProperty(e,"__isScriptSetup",{enumerable:!1,value:!0}),e}});function T(a,o,e,r,p,c){return t(),_(r.StreamlitComponent,{component:r.Component,"client:load":""})}const I=n(x,[["render",T]]);export{I as default};
